UI/SearchWidget.py

branch
Py2 comp.
changeset 3484
645c12de6b0c
parent 3178
f25fc1364c88
parent 3366
6084bb3c3911
child 3656
441956d8fce5
--- a/UI/SearchWidget.py	Sun Mar 30 22:00:14 2014 +0200
+++ b/UI/SearchWidget.py	Thu Apr 03 23:05:31 2014 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the search box for the shel, terminal and log viewer.
+Module implementing the search box for the shell, terminal and log viewer.
 """
 
 from __future__ import unicode_literals
@@ -19,7 +19,7 @@
 
 class SearchWidget(QWidget, Ui_SearchWidget):
     """
     Class implementing the search box for the shel, terminal and log viewer.
     
     @signal searchNext(text, caseSensitive, wholeWord) emitted when the user
         pressed the next button (string, boolean, boolean)
@@ -62,6 +62,9 @@
         
         self.findtextCombo.lineEdit().returnPressed.connect(
             self.__findByReturnPressed)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     @pyqtSlot()
     def on_closeButton_clicked(self):
@@ -177,4 +180,4 @@
         else:
             txt = self.findtextCombo.currentText()
             self.statusLabel.setText(
-                self.trUtf8("'{0}' was not found.").format(txt))
+                self.tr("'{0}' was not found.").format(txt))
@@ -19,7 +19,7 @@
 class SearchWidget(QWidget, Ui_SearchWidget):
     """
-    Class implementing the search box for the shel, terminal and log viewer.
+    Class implementing the search box for the shell, terminal and log viewer.
     
     @signal searchNext(text, caseSensitive, wholeWord) emitted when the user

eric ide

mercurial